Enum sp_storage::ChildInfo [−][src]
pub enum ChildInfo {
ParentKeyId(ChildTrieParentKeyId),
}Expand description
Information related to a child state.
Variants
ParentKeyId(ChildTrieParentKeyId)This is the one used by default.
Tuple Fields of ParentKeyId
Implementations
Instantiates child information for a default child trie
of kind ChildType::ParentKeyId, using an unprefixed parent
storage key.
Same as new_default but with Vec<u8> as input.
Try to update with another instance, return false if both instance are not compatible.
Returns byte sequence (keyspace) that can be use by underlying db to isolate keys.
This is a unique id of the child trie. The collision resistance of this value
depends on the type of child info use. For ChildInfo::Default it is and need to be.
Returns a reference to the location in the direct parent of this trie but without the common prefix for this kind of child trie.
Return a the full location in the direct parent of this trie.
Returns a the full location in the direct parent of this trie.
Returns the type for this child info.